==> spqr-0.10.0-sources.jar: io/leangen/graphql/metadata/DirectiveArgument.java <==
package io.leangen.graphql.metadata;

import io.leangen.graphql.util.ClassUtils;

import java.lang.annotation.Annotation;
import java.lang.reflect.AnnotatedType;
import java.util.stream.Collectors;

public class DirectiveArgument {

    private final String name;
    private final String description;
    private final TypedElement typedElement;
    private final Object value;
    private final Object defaultValue;
    private final Annotation annotation;

    public DirectiveArgument(String name, String description, TypedElement element, Object value, Object defaultValue, Annotation annotation) {
        this.name = name;
        this.typedElement = element;
        this.description = description;
        this.value = value;
        this.defaultValue = defaultValue;
        this.annotation = annotation;
    }

    public String getName() {
        return name;
    }

    public AnnotatedType getJavaType() {
        return typedElement.getJavaType();
    }

    public String getDescription() {
        return description;
    }

    public Object getValue() {
        return value;
    }

    public Object getDefaultValue() {
        return defaultValue;
    }

    public TypedElement getTypedElement() {
        return typedElement;
    }

    public Annotation getAnnotation() {
        return annotation;
    }

    @Override
    public String toString() {
        return String.format("Directive argument '%s' of type %s bound to [%s]", name, ClassUtils.toString(getJavaType()),
                typedElement.getElements().stream().map(ClassUtils::toString).collect(Collectors.joining()));
    }
}

==> spqr-0.12.3-sources.jar: io/leangen/graphql/metadata/DirectiveArgument.java <==
package io.leangen.graphql.metadata;

import io.leangen.graphql.util.ClassUtils;

import java.lang.annotation.Annotation;
import java.lang.reflect.AnnotatedType;
import java.util.stream.Collectors;

public class DirectiveArgument {

    private final String name;
    private final String description;
    private final TypedElement typedElement;
    private final Object value;
    private final DefaultValue defaultValue;
    private final Annotation annotation;

    public DirectiveArgument(String name, String description, TypedElement element, Object value, DefaultValue defaultValue, Annotation annotation) {
        this.name = name;
        this.typedElement = element;
        this.description = description;
        this.value = value;
        this.defaultValue = defaultValue;
        this.annotation = annotation;
    }

    public String getName() {
        return name;
    }

    public AnnotatedType getJavaType() {
        return typedElement.getJavaType();
    }

    public String getDescription() {
        return description;
    }

    public Object getValue() {
        return value;
    }

    public DefaultValue getDefaultValue() {
        return defaultValue;
    }

    public TypedElement getTypedElement() {
        return typedElement;
    }

    public Annotation getAnnotation() {
        return annotation;
    }

    @Override
    public String toString() {
        return String.format("Directive argument '%s' of type %s bound to [%s]", name, ClassUtils.toString(getJavaType()),
                typedElement.getElements().stream().map(ClassUtils::toString).collect(Collectors.joining()));
    }
}
